==> release.12.0.73.1.tgz: prontus/cpan/js-local/prontus_edit/customTool_newfile.js <==
(function() {
    let FileExplorerTool_NewfileCustom = function(fe) {
        if (!(this instanceof FileExplorerTool_NewfileCustom))  return new FileExplorerTool_NewfileCustom(fe);

        let enabled = false;
        let node = fe.AddToolbarButton('fe_fileexplorer_folder_tool_new_file', fe.Translate('New File'));
        let configModalConfirm = {
            title: "Crear archivo",
            content: '' +
                '<form action="" class="formName3">' +
                '<div class="form-group">' +
                '<label>Ingresa Nombre del Archivo:</labelace>' +
                '<input type="text" id="nombre_nuevo_archivo" placeholder="Nombre del Archivo" class="name form-control" required>' +
                '</div>' +
                '</form>',
            icon: "glyphicon glyphicon-question-sign",
            columnClass: 'col-md-offset-6 col-md-12',
            containerFluid: true,
            onContentReady: function () {
                // bind to events
                var jc = this;
                this.$content.find('form').on('submit', function (e) {
                    // if the user submits the form by pressing enter in the field.
                    e.preventDefault();
                    jc.$$ok.trigger('click'); // reference the button and click it
                });
            },
            buttons: {
                ok: {
                    text: "Crear",
                    keys: ['enter'],
                    btnClass: 'hovwhite radius15 noborder txtnextwhite pad-top-bot7 pad-lef-rig20 int-nextgreen nextgreen',
                    action: function () {
                        var nombre_nuevo_archivo = $('#nombre_nuevo_archivo').val();
                        if (!nombre_nuevo_archivo) {
                            $.alert({
                                type: 'red',
                                icon: "glyphicon glyphicon-remove-circle",
                                title: "Error",
                                content: 'Ingresa un nombre válido',
                                columnClass: 'medium'
                            });
                            return false;

                        } else if (nombre_nuevo_archivo.match(/\./)) {
                            NewFileHandler(fe, nombre_nuevo_archivo);
                        } else {
                            $.alert({
                                type: 'red',
                                icon: "glyphicon glyphicon-remove-circle",
                                title: "Error",
                                content: 'Ingresa una extensión válida',
                                columnClass: 'medium'
                            });
                            return false;
                        }
                    }
                },
                cancel: {
                    text: "Cancelar",
                    action: function () {}
                }
            }
        };

        let NewFileHandler = function (fe, nomNewFile) {
            let paths = fe.GetCurrentFolder().GetPath();
            let path = "";
            let entries = fe.GetSelectedFolderEntries();

            paths.forEach(function (item) {
                path += item[0] + "/";
            });

            path = path.substring(0, path.length - 1);

            let xhr = new fe.PrepareXHR({
                url: '/cgi-cpn/prontus_edit_guardar.cgi',
                params: {
                    _prontus_id: $("body").data("prontus-id"),
                    sbm_accion: "Nuevo",
                    _curr_dir: path,
                    nom_new_file: nomNewFile
                },
                onsuccess: function(e) {
                    let data = JSON.parse(e.target.response);

                    if (data.status == 1) {
                        fe.RefreshFolders(true);
                    } else {
                        showModalAlert({
                            title: 'Error al crear el archivo',
                            type: 'red',
                            msg: data.msg
                        });
                    }

                },
                onerror: function(e) {
                    showModalAlert({
                        title: 'Error al crear el archivo',
                        type: 'red',
                        msg: "Ocurrió un error al tratar de crear el archivo."
                    });
                }
            });

            xhr.Send();
        };

        // Handle clicks.
        let ClickHandler = function(e) {
            if (enabled) {
                showModalConfirm(configModalConfirm);
            }
        };

        node.addEventListener('click', ClickHandler);

        let UpdateToolHandler = function(currfolder, attrs) {
            let prevenabled = enabled;

            enabled = true;

            if (prevenabled !== enabled) {
                if (enabled) {
                    node.classList.remove('fe_fileexplorer_disabled');
                } else {
                    node.classList.add('fe_fileexplorer_disabled');
                }

                fe.ToolStateUpdated();
            }
        };

        fe.addEventListener('update_tool', UpdateToolHandler);

        let DestroyToolHandler = function() {
            node.removeEventListener('click', ClickHandler);
        };

        fe.addEventListener('destroy', DestroyToolHandler);
    };

    window.FileExplorer.RegisterTool(1, FileExplorerTool_NewfileCustom);
})();

==> release.12.3.1.2.tgz: prontus/cpan/js-local/prontus_edit/customTool_newfile.js <==
(function() {
    let FileExplorerTool_NewfileCustom = function(fe) {
        if (!(this instanceof FileExplorerTool_NewfileCustom))  return new FileExplorerTool_NewfileCustom(fe);

        let enabled = false;
        let node = fe.AddToolbarButton('fe_fileexplorer_folder_tool_new_file', fe.Translate('New File'));
        let configModalConfirm = {
            title: ProntusL10n.get('prontus_edit_create_file_label'),
            content: '' +
                '<form action="" class="formName3">' +
                '<div class="form-group">' +
                '<label>'+ProntusL10n.get('prontus_edit_filename_label')+'</labelace>' +
                '<input type="text" id="nombre_nuevo_archivo" placeholder="'+ProntusL10n.get('Nombre del Archivo')+'" class="name form-control" required>' +
                '</div>' +
                '</form>',
            icon: "glyphicon glyphicon-question-sign",
            columnClass: 'col-md-offset-6 col-md-12',
            containerFluid: true,
            onContentReady: function () {
                // bind to events
                var jc = this;
                this.$content.find('form').on('submit', function (e) {
                    // if the user submits the form by pressing enter in the field.
                    e.preventDefault();
                    jc.$$ok.trigger('click'); // reference the button and click it
                });
            },
            buttons: {
                ok: {
                    text: ProntusL10n.get('prontus_edit_create_label'),
                    keys: ['enter'],
                    btnClass: 'hovwhite radius15 noborder txtnextwhite pad-top-bot7 pad-lef-rig20 int-nextgreen nextgreen',
                    action: function () {
                        var nombre_nuevo_archivo = $('#nombre_nuevo_archivo').val();
                        if (!nombre_nuevo_archivo) {
                            $.alert({
                                type: 'red',
                                icon: "glyphicon glyphicon-remove-circle",
                                title: ProntusL10n.get('global_error_title'),
                                content: 'Ingresa un nombre válido',
                                columnClass: 'medium'
                            });
                            return false;

                        } else if (nombre_nuevo_archivo.match(/\./)) {
                            NewFileHandler(fe, nombre_nuevo_archivo);
                        } else {
                            $.alert({
                                type: 'red',
                                icon: "glyphicon glyphicon-remove-circle",
                                title: ProntusL10n.get('global_error_title'),
                                content: ProntusL10n.get('prontus_edit_input_valid_ext'),
                                columnClass: 'medium'
                            });
                            return false;
                        }
                    }
                },
                cancel: {
                    text: ProntusL10n.get('global_cancel_label'),
                    action: function () {}
                }
            }
        };

        let NewFileHandler = function (fe, nomNewFile) {
            let paths = fe.GetCurrentFolder().GetPath();
            let path = "";
            let entries = fe.GetSelectedFolderEntries();

            paths.forEach(function (item) {
                path += item[0] + "/";
            });

            path = path.substring(0, path.length - 1);

            let xhr = new fe.PrepareXHR({
                url: '/cgi-cpn/prontus_edit_guardar.cgi',
                params: {
                    _prontus_id: $("body").data("prontus-id"),
                    action: "new",
                    _curr_dir: path,
                    nom_new_file: nomNewFile
                },
                onsuccess: function(e) {
                    let data = JSON.parse(e.target.response);

                    if (data.status == 1) {
                        fe.RefreshFolders(true);
                    } else {
                        showModalAlert({
                            title: ProntusL10n.get('prontus_edit_create_error_label'),
                            type: 'red',
                            msg: data.msg
                        });
                    }

                },
                onerror: function(e) {
                    showModalAlert({
                        title: ProntusL10n.get('prontus_edit_create_error_label'),
                        type: 'red',
                        msg: ProntusL10n.get('prontus_edit_create_error')
                    });
                }
            });

            xhr.Send();
        };

        // Handle clicks.
        let ClickHandler = function(e) {
            if (enabled) {
                showModalConfirm(configModalConfirm);
            }
        };

        node.addEventListener('click', ClickHandler);

        let UpdateToolHandler = function(currfolder, attrs) {
            let prevenabled = enabled;

            enabled = true;

            if (prevenabled !== enabled) {
                if (enabled) {
                    node.classList.remove('fe_fileexplorer_disabled');
                } else {
                    node.classList.add('fe_fileexplorer_disabled');
                }

                fe.ToolStateUpdated();
            }
        };

        fe.addEventListener('update_tool', UpdateToolHandler);

        let DestroyToolHandler = function() {
            node.removeEventListener('click', ClickHandler);
        };

        fe.addEventListener('destroy', DestroyToolHandler);
    };

    window.FileExplorer.RegisterTool(1, FileExplorerTool_NewfileCustom);
})();
